@@ -10,7 +10,7 @@
 #   - Ensure smartotu log file are writable from apache
 #
 
-source /etc/init.d/otu_functions
+source /usr/lib/otu_functions
 
 # If we are not Otu but /otu directory exists remove it (otu5000 to eotdrv2 conversion by manufacturing)
 is_cotu_hw
@@ -68,7 +68,7 @@ if [ ! -f /acterna/release/bin/Otu.ver ] && [ -f /etc/acterna/Otu.ver ] ; then
 fi
 
 # In enhance security mode we have to check every boot that users have not been added during an upgrade
-if [ "$(upg_environment g Enhanced_Security)" = "true" ] ; then
+if [ "$(/sbin/fw_printenv -n Enhanced_Security)" = "true" ] ; then
     bash /usr/lib/jdsu/scripts/update_user_list.sh "DEL" > /dev/null 2>&1
 fi
 
