@@ -6,7 +6,7 @@
 #  - Disable tftp if necessary (tftp is required for eotdrv2)
 #
 
-source /etc/init.d/otu_functions
+source /usr/lib/otu_functions
 
 LOG_PART_RESCUE="/dev/mmcblk1p7"
 
