@@ -81,7 +81,15 @@ class SMTSession
         
         //Mandatory to use objects (SMTFileSessionHandler) as session manager.
         register_shutdown_function('session_write_close');
-        
+
+        $protocol = apache_getenv('HTTPS') ? 'https:' : 'http:';
+        $sec_protocol = 'https';
+        if(strpos($protocol, $sec_protocol) !== false){
+           @ini_set('session.cookie_secure', '1');
+        } else {
+           @ini_set('session.cookie_secure', '0');
+        }
+
         //start or restore php session
     	session_start();
     	
@@ -114,7 +122,15 @@ class SMTSession
     {
         //test if a session is already running
         $this->closeSession();
-        
+
+        $protocol = apache_getenv('HTTPS') ? 'https:' : 'http:';
+        $sec_protocol = 'https';
+        if(strpos($protocol, $sec_protocol) !== false){
+           @ini_set('session.cookie_secure', '1');
+        } else {
+           @ini_set('session.cookie_secure', '0');
+        } 
+
         //start session
         session_start();                
         //update last application access to track timeout
@@ -379,4 +395,4 @@ class SMTSession
     }    
 }
 
-?>
\ No newline at end of file
+?>
