@@ -59,6 +59,8 @@ use app\serviceshelper\alarm\SMTAlarmFactory;
 use app\serviceshelper\otdr\SMTBaseOtdrTraceFileUtil;
 use app\serviceshelper\otdr\SMTTraceFileType;
 use app\serviceshelper\monitoring\SMTTestMode;
+use app\serviceshelper\otdr\SMTUfomFileUtil;
+use app\view\SMTUfomFileDownloadPage;
 
 /**
  * Service to setup and list link-tests.
@@ -736,50 +738,95 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
                 //test if a link exists:
                 $linkId = $this->sendReceive( SMTOtuApi::getLinkListPerPortCommand( intval($portid), intval($portid) ) );
 
-                if ( SMTLinkTest::checkLinkTestId( $linkId ) )
-                {
-                	//does a test exist?
-                	$testId = SMTLinkTest::parseLinkTestId( $this->sendReceive( SMTOtuApi::getTestOnLinkCommand( $linkId ) ) );
-                	if ( SMTLinkTest::checkLinkTestId($testId) )
+                	if ( SMTOtdrTraceType::isUfomFileType( $traceType) )
                 	{
-                	    switch ($traceType)
-                	    {
-                	        case SMTOtdrTraceType::REF:
-                	            $otdrTraceType = SMTOtdrTraceType::OTU_REFERENCE_TRACE;
-    			                $traceName = sprintf( SMTOtdrTraceFileUtil::REF_TRACE_NAME, $portid);
-    			                $traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.$traceName;
-                	            break;
-                	        case SMTOtdrTraceType::ALARM:
-                	            $otdrTraceType = SMTOtdrTraceType::OTU_ALARM_TRACE;
-                	            $alarmHelper = new SMTAlarm();
-                        		$alarmHelper->setContext( $this->getContext() );
-                        		$alarmDto = $alarmHelper->fetchOpticalAlarmFromTest( $testId );
-                        		
-                        		if ( $alarmDto != NULL )
-                        		{    		 
-                        			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portid, $alarmDto->getDiscriminator() );
-                        		    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);  		   
-                        		}
-                        		else
-                        		{
-                        		    throw new SMTAlarmException( SMTAlarmException::ERROR_ALARM_RETRIEVAL_FAILED, "testId = ".$testId );
-                        		}
-                	        	break;
-            	        	case SMTOtdrTraceType::ACQ:
-            	        	    $otdrTraceType = SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE;
-            	        	    //for trace download we want always a SOR file
-            	        	    $traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portid, $isLoc, FALSE);
-            	        		break;
-            	        	default:
-            	        	    throw new SMTLinkTestException( SMTLinkTestException::ERROR_MISSING_OTDR_TRACE, "invalid trace type ".$traceType );
-            	        	    break;
-                	    }
-                	    
-                	    SMTLogger::getInstance()->trace( sprintf("Retrieve otdr trace file %s, for type %s ",  $traceFilePath, $otdrTraceType ), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);                	    
-                	    $page = new SMTOtdrTraceFileDownloadPage( $traceFilePath, $otdrTraceType );                	    
-                	    $this->getContext()->getHttpResponse()->send( $page );
+                		switch ($traceType)
+                		{
+                			case SMTOtdrTraceType::UFOM_CSV:
+                				$traceFilePath = SMTUfomFileUtil::retrieveUfomLastCsvFile();
+                				break;
+                			case SMTOtdrTraceType::UFOM_OLDEST_CSV:
+                				$traceFilePath = SMTUfomFileUtil::retrieveUfomLastCsvFile(FALSE);
+                				break;
+                			case SMTOtdrTraceType::UFOM_INFO:
+                				$traceFilePath = SMTUfomFileUtil::retrieveUfomLastDebugFile();
+                				break;
+                			case SMTOtdrTraceType::UFOM_REF_SOR:
+                				$traceFilePath = SMTUfomFileUtil::retrieveUfomRefSorFile();
+                				break;
+                			case SMTOtdrTraceType::UFOM_SOR:
+                				$traceFilePath = SMTUfomFileUtil::retrieveUfomLastSorFile();
+                				break;
+                			default:
+                				throw new SMTLinkTestException( SMTLinkTestException::ERROR_MISSING_OTDR_TRACE, "invalid trace type ".$traceType );
+                				break;
+                		}
+                		
+                		SMTLogger::getInstance()->trace( sprintf("Retrieve ufom file %s, for type %s ",  $traceFilePath, $traceType), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+                		$page = new SMTUfomFileDownloadPage( $traceFilePath );
+                		$this->getContext()->getHttpResponse()->send( $page, FALSE );
+                		//delete file uploaded before exit
+                		switch ($traceType)
+                		{
+                			case SMTOtdrTraceType::UFOM_CSV:
+                			case SMTOtdrTraceType::UFOM_OLDEST_CSV:
+                				$traceFilePath = SMTUfomFileUtil::deleteUfomCsvFile($traceFilePath);
+                				break;
+                			case SMTOtdrTraceType::UFOM_INFO:
+                				$traceFilePath = SMTUfomFileUtil::deleteUfomDebugFiles();
+                				break;
+                			case SMTOtdrTraceType::UFOM_SOR:
+                				$traceFilePath = SMTUfomFileUtil::deleteUfomSorFile( $traceFilePath );
+                				break;
+                			default:
+                				break;
+                		}
+                		exit(0);
+                	}
+                	else if ( SMTLinkTest::checkLinkTestId( $linkId ) )
+                	{
+	                	//does a test exist?
+	                	$testId = SMTLinkTest::parseLinkTestId( $this->sendReceive( SMTOtuApi::getTestOnLinkCommand( $linkId ) ) );
+	                	if ( SMTLinkTest::checkLinkTestId($testId) )
+	                	{
+	                	    switch ($traceType)
+	                	    {
+	                	        case SMTOtdrTraceType::REF:
+	                	            $otdrTraceType = SMTOtdrTraceType::OTU_REFERENCE_TRACE;
+	    			                $traceName = sprintf( SMTOtdrTraceFileUtil::REF_TRACE_NAME, $portid);
+	    			                $traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.$traceName;
+	                	            break;
+	                	        case SMTOtdrTraceType::ALARM:
+	                	            $otdrTraceType = SMTOtdrTraceType::OTU_ALARM_TRACE;
+	                	            $alarmHelper = new SMTAlarm();
+	                        		$alarmHelper->setContext( $this->getContext() );
+	                        		$alarmDto = $alarmHelper->fetchOpticalAlarmFromTest( $testId );
+	                        		
+	                        		if ( $alarmDto != NULL )
+	                        		{    		 
+	                        			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portid, $alarmDto->getDiscriminator() );
+	                        		    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);  		   
+	                        		}
+	                        		else
+	                        		{
+	                        		    throw new SMTAlarmException( SMTAlarmException::ERROR_ALARM_RETRIEVAL_FAILED, "testId = ".$testId );
+	                        		}
+	                	        	break;
+	            	        	case SMTOtdrTraceType::ACQ:
+	            	        	    $otdrTraceType = SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE;
+	            	        	    //for trace download we want always a SOR file
+	            	        	    $traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portid, $isLoc, FALSE);
+	            	        		break;
+	            	        	default:
+	            	        	    throw new SMTLinkTestException( SMTLinkTestException::ERROR_MISSING_OTDR_TRACE, "invalid trace type ".$traceType );
+	            	        	    break;
+	                	    }
+	                	    
+	                	    SMTLogger::getInstance()->trace( sprintf("Retrieve otdr trace file %s, for type %s ",  $traceFilePath, $otdrTraceType ), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);                	    
+	                	    $page = new SMTOtdrTraceFileDownloadPage( $traceFilePath, $otdrTraceType );
+	                	    $this->getContext()->getHttpResponse()->send( $page );
+	                	}
                 	}
-                }
             }
             else
             {
