@@ -144,7 +144,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$this->switchManager->disableSequencer(FALSE);
     		
     		// si l'on n'est pas en mode SmartOTU, on force la detection si elle n'a jamais ete faite
-    		if ( !SMTOtuMode::isSmartOtu() && !SMTOtuStatusCacheDto::getSwitchDetectedOnce() )
+    		if ( !SMTOtuMode::isSmartOtuFamily() && !SMTOtuStatusCacheDto::getSwitchDetectedOnce() )
     		{
     			$detectOsx = TRUE;
     		}
