@@ -134,6 +134,23 @@ class SMTFirewall extends SMTServiceHelper
 		    throw new SMTIOException(SMTIOException::FILE_NOT_FOUND, "custom firewall");    	    
     	}
     }
-
+    /**
+     * Reset custom firewall content file with default content
+     * @throws Exception
+     */
+    function resetCustomFileContent()
+    {
+    	try
+    	{
+    		$this->send( SMTOtuApi::getFirewallResetCustomContentCommand() );
+    		SMTLogger::getInstance()->trace( "Reset firewall custom content.", SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+    	}
+    	catch ( \Exception $e )
+    	{
+    		SMTLogger::getInstance()->traceException( $e );
+    		throw $e;
+    	}
+    }
+    
 }
 ?>
