@@ -31,6 +31,7 @@ final class SMTLicenseList
 	const TAPPING_MON= 'OTU_TAPPING';
 	const LIGHT_SOURCE= 'LIGHT_SOURCE';
 	const REST_API= 'REST_API';
+	const ULTRAFAST_MON='ULTRAFAST_MON';
 	
 	const OTU_OPTION_HIGH_SEC = 'HIGHSEC';
 	const OTU_OPTION_SSH_KEY_ACCESS = 'ACCESS';
@@ -42,6 +43,7 @@ final class SMTLicenseList
 	const OTU_OPTION_TAPPING_MONITORING = 'TAPPING';
 	const OTU_OPTION_LIGHT_SOURCE= 'LIGHT_SOURCE';
 	const OTU_OPTION_REST_API= 'REST_API';
+    const OTU_OPTION_ULTRAFAST_MON='ULTRAFAST_MON';
 
 	const ISU_OPTION_SAA_L2_MONITORING = 'SMART_ACCESS_L2';
 	
@@ -63,7 +65,8 @@ final class SMTLicenseList
 										self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA,
 			                            self::OTU_OPTION_TAPPING_MONITORING=>self::TAPPING_MON,
 										self::OTU_OPTION_LIGHT_SOURCE=>self::LIGHT_SOURCE,
-										self::OTU_OPTION_REST_API=>self::REST_API
+										self::OTU_OPTION_REST_API=>self::REST_API,
+	                                    self::OTU_OPTION_ULTRAFAST_MON=>self::ULTRAFAST_MON
 	);
 	
 	static function getLicenseName( $scpiKey )
