@@ -164,7 +164,7 @@ class SMTModule extends SMTServiceHelper
     	//module found in MOD1 or MOD2 or MOD3
     	$difference = ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD1 ) ) != SMTOtuApi::RES_OK );
     	$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD2 ) ) != SMTOtuApi::RES_OK );
-    	if ( (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2()) && !SMTOtuMode::isONMS() )
+    	if ( (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2()) && !SMTOtuMode::isONMS() && !SMTOtuMode::isROTAU() && !SMTOtuMode::isUFOM() )
     	{
     		$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD3 ) ) != SMTOtuApi::RES_OK );
     	}
