@@ -44,8 +44,9 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
         $this->setSwitchDecoder( parent::GLOB, $code );
         
         // distributor OSX musn't be fetched twice
+        $hasDistributor = $this->getSwitchDecoder( parent::GLOB)->hasOSUDistributor();
         $nbOsx = $this->getSwitchDecoder( parent::GLOB)->getOSUCount();
-        if ( $nbOsx >= self::OSU_DISTRIBUTOR_INDEX)
+        if ( $hasDistributor && ($nbOsx >= self::OSU_DISTRIBUTOR_INDEX) )
         {
         	$nbOsx = self::OSU_DISTRIBUTOR_INDEX -1 ;
         }
@@ -59,10 +60,9 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
         }
          
         //distributor OSU is at address 31
-        $osuDistributor = $this->getSwitchDecoder( parent::GLOB)->getOSUDistributor();
-        if ( $osuDistributor != '' )
+        if ( $hasDistributor)
         {
-            $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, $osuDistributor ) );
+        	$result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, $this->getSwitchDecoder( parent::GLOB)->getOSUDistributor()) );
             list( $device, $code, $test ) = explode(',', $result);
             $this->setSwitchDecoder( parent::OSU_DISTRIBUTOR, $code );
         }        
@@ -115,6 +115,28 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
     	}
     }
     
+    function hasMolexOSU()
+    {
+    	if ( $this->getSwitchDecoder( self::GLOB) == NULL )
+    	{
+    		$result = $this->socket->sendReceive( SMTOtuApi::CMD_get_osu_det_type );
+    		return strcasecmp('MOLEX', $result) == 0;
+    	}
+    	
+    	return ($this->getSwitchDecoder( self::GLOB) != NULL)? $this->getSwitchDecoder( self::GLOB)->hasMolexOSU(): FALSE;
+    }
+    
+    function hasJdsuOSU()
+    {
+    	if ( $this->getSwitchDecoder( self::GLOB) == NULL )
+    	{
+    		$result = $this->socket->sendReceive( SMTOtuApi::CMD_get_osu_det_type );
+    		return strcasecmp('JDSU', $result) == 0;
+    	}
+    	
+    	return ($this->getSwitchDecoder( self::GLOB) != NULL)? $this->getSwitchDecoder( self::GLOB)->hasJdsuOSU(): FALSE;
+    }
+    
     /**
      * Retrieve internal switch and build the switch Dto
      * 
