@@ -114,11 +114,14 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
 //     		}
 //     	}
     	
+        // check difference before retrieving config (to have serial numbers updated... )
+		$isSwitchDifference = $this->isDifference($forceDetection);
+
         //retrieve macro switch config:
         $this->switchConfig = self::retrieveConfiguredSwitch($this->getContext()->getOtuSocket());
         
         //retrieve detection if a difference exists and if detection has not already been retrieved and if a detection exists
-        if ( $this->isDifference($forceDetection) && ($this->switchDetect == NULL) && $this->hasDetection($forceDetection) )
+        if ( $isSwitchDifference && ($this->switchDetect == NULL) && $this->hasDetection($forceDetection) )
         {
         	$this->switchDetect = self::retrieveDetectedSwitch($this->getContext()->getOtuSocket(), FALSE);
         }
@@ -441,7 +444,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
         if ( $detectedSwitch != NULL )
         {
         	//in SmartOTU mode, if OSX are used, topology must be extended
-        	if ( SMTOtuMode::isSmartOtu() && $detectedSwitch->hasOsx() )
+        	if ( SMTOtuMode::isSmartOtuFamily() && $detectedSwitch->hasOsx() )
         	{
         		try
         		{
