@@ -20,6 +20,8 @@ then
       # add new pub key in /home/secuser/.ssh/authorized_keys
       echo "">> $Authorized
       awk '{print $1 " " $2 " custom_key.pub" }' /home/secuser/.ssh/$Custom_Key.pub >> $Authorized
+      # delete pub key
+      rm /home/secuser/.ssh/$Custom_Key.pub
       exit 0
    else
       echo "Missing public key"
