@@ -9,7 +9,8 @@ eMMC_Blk = {
     "mts4000ng": 0,
     "mts2000ng": 0,
     "mts1000":   0,
-    "eotdrv2":   1
+    "eotdrv2":   1,
+    "nanoeotdr": 0
 }
 
 @DIAG("Test eMMC")
