@@ -34,9 +34,18 @@ LedsConfigurations = {
     "eotdrv2": {
         "TEST":"led_test",
         "SOFT_UPG":"led_soft_upg"
+    },
+    "nanoeotdr": {
+        "TEST":"led_test",
+        "SOFT_UPG":"led_soft_upg",
+        "ON_R":"led_on_r",
+        "ON_G":"led_on_g",
+        "STATUS_R":"led_status_r",
+        "ETH":"led_eth",
     }
 }
 
+
 @DIAG("Led test")
 def t_led(cmd):
     conf = LedsConfigurations[mts.getMachineName()]
