@@ -87,11 +87,11 @@ def t_cotu_fan(cmd):
         {'name': 'GPIO_OTU_FAN1', 'gpio': gpio_base + 13, 'dir': 'out', 'opposite_pin': 'gpio_b87_fan1_otu_on'},
         {'name': 'GPIO_OTU_FAN2', 'gpio': gpio_base + 14, 'dir': 'out', 'opposite_pin': 'gpio_b87_fan2_otu_on'},
         {'name': 'GPIO_OTU_FAN3', 'gpio': gpio_base + 15, 'dir': 'out', 'opposite_pin': 'gpio_b87_fan3_otu_on'},
-        {'name': 'GPIO_OTU_FAN_PWM', 'gpio': gpio_base + 16, 'dir': 'out', 'opposite_pin': 'gpio_b87_fan_otu_pwm'},
         {'name': 'GPIO_OTU_FAN_TACH1', 'gpio': gpio_base + 17, 'dir': 'in', 'opposite_pin': 'gpio_b87_fan1_otu_tach'},
         {'name': 'GPIO_OTU_FAN_TACH2', 'gpio': gpio_base + 18, 'dir': 'in', 'opposite_pin': 'gpio_b87_fan2_otu_tach'},
         {'name': 'GPIO_OTU_FAN_TACH3', 'gpio': gpio_base + 19, 'dir': 'in', 'opposite_pin': 'gpio_b87_fan3_otu_tach'},
     ]
+#        {'name': 'GPIO_OTU_FAN_PWM', 'gpio': gpio_base + 16, 'dir': 'out', 'opposite_pin': 'gpio_b87_fan_otu_pwm'},
     print_info("Configuring GPIOs")
     # configure GPIOs and init everything to 0
     try:
@@ -640,7 +640,7 @@ def t_opsw_pwr_sply_test(cmd):
 
 @DIAG("Test osx communication port")
 def t_cotu_osx(cmd):
-    TTYOSX = '/dev/ttyPS0'
+    TTYOSX = '/dev/ttyS0'
     OSX_IDN_QUERY = bytes([0x81, 0x01, 0x00, 0x00, 0x02, 0x00, 0x01, 0x00, 0x6a, 0xdc])
 
     ser = serial.Serial(TTYOSX, 2400, timeout=5)
